@@ -33,14 +33,14 @@ import time
 from cli.ui_utils import menu_options, app_header, format_msg
 from cli.utils import (get_correct_answer, path_fixer, SetupConfig,
                        _directory_fixer, install_client_package,
-                       write_client_config, dev_machine_check)
+                       write_client_config)
 
 # framework stuff
 from not_so_tuf import (NotSoTuf, Client, FileCrypt, KeyHandler,
                         PackageHandler, Uploader)
 
 from not_so_tuf.compat import input_, print_function
-from not_so_tuf.utils import _cwd, FROZEN, ask_yes_no
+from not_so_tuf.utils import cwd_, FROZEN, ask_yes_no
 from not_so_tuf.version import __version__
 
 
@@ -83,7 +83,7 @@ class Ui(object):
 
     def main(self):
         log.debug('Main menu')
-        self.cwd = _cwd
+        self.cwd = cwd_
         dec_path = os.path.join(self.cwd, 'config.data')
         enc_path = os.path.join(self.cwd, 'config.data.enc')
         if not os.path.exists(dec_path) and not os.path.exists(enc_path):
@@ -232,7 +232,7 @@ class Ui(object):
                   ' folder password deletion'))
 
             log.debug('Attempting to copy decrypted config')
-            filename = os.path.join(_cwd, 'config.data')
+            filename = os.path.join(cwd_, 'config.data')
             self.file_crypt.new_file(filename)
             self.file_crypt.decrypt()
             try:
@@ -422,7 +422,7 @@ class Ui(object):
         self.nst.update_config(obj)
         self.update_mods(self.nst)
         log.debug('Saving Config')
-        filename = os.path.join(_cwd, 'config.data')
+        filename = os.path.join(cwd_, 'config.data')
         self.file_crypt.new_file(filename)
         self.file_crypt.decrypt()
         with open(filename, 'w') as f:
@@ -432,7 +432,7 @@ class Ui(object):
 
     def load_config(self):
         log.debug('Loading Config')
-        filename = os.path.join(_cwd, 'config.data')
+        filename = os.path.join(cwd_, 'config.data')
         self.file_crypt.new_file(filename)
         self.file_crypt.decrypt()
         with open(filename, 'r') as f:
@@ -443,7 +443,7 @@ class Ui(object):
 
     def copy_decrypted_config(self):
         log.debug('Attempting to copy decrypted config')
-        filename = os.path.join(_cwd, 'config.data')
+        filename = os.path.join(cwd_, 'config.data')
         self.file_crypt.new_file(filename)
         self.file_crypt.decrypt()
         try:
