@@ -111,6 +111,7 @@ def get_correct_answer(question, default=None, required=False,
             print('You have to enter a value\n\n')
             raw_input('Press enter to continue')
             print('\n\n')
+            answer = None
             continue
         if answer == '' and default is not None:
             answer = default
@@ -153,12 +154,17 @@ def install_client_package(test=False):
     package_name = 'not_so_tuf'
     if test:
         dir_ = os.getcwd()
-        version_file = 0
+        version_file = '0'
     else:
         dir_ = os.path.abspath(sys._MEIPASS)
         url = ('https://raw.github.com/JohnyMoSwag/Not-So-'
                'TUF/master/not_so_tuf/version.py')
-        version_file = urllib2.urlopen(url).read()
+        try:
+            version_file = urllib2.urlopen(url).read()
+            version_file = version_file.replace('__version__ = ', '')
+        except Exception as e:
+            log.warning(str(e), exc_info=True)
+            version_file = '0'
 
     if __version__ != version_file:
         if test:
