@@ -32,7 +32,7 @@ from not_so_tuf.config import Config
 from not_so_tuf.downloader import FileDownloader
 from not_so_tuf.patcher import Patcher
 from not_so_tuf.utils import (ChDir, rsa_verify, _version_string_to_tuple,
-                              _version_tuple_to_string, platform_, FROZEN)
+                              platform_, FROZEN)
 from not_so_tuf.version import __version__
 
 log = logging.getLogger(__name__)
