@@ -28,14 +28,14 @@ import sys
 import time
 
 from not_so_tuf.exceptions import FileCryptError
+import beefish
 from not_so_tuf.utils import cwd_
 
 try:
-    import beefish
     import keyring
     import pbkdf2
     import triplesec
-except Exception as e:
+except ImportError:
     raise FileCryptError('Must have keyring, pbkdf2 & triplesec installed.',
                          expected=True)
 
@@ -91,8 +91,7 @@ class FileCrypt(object):
             log.warning('No file to process yet.')
 
     def encrypt(self):
-        """Will encrypt a file with triplesec.  Will encrypt file passed
-        in during object initialization or new_file method."""
+        """Will encrypt a file with triplesec"""
         if self.filename is None:
             raise FileCryptError('Must set filename with new_file '
                                  'method call before you can encrypt',
@@ -113,12 +112,14 @@ class FileCrypt(object):
         self._del_internal_password()
 
     def decrypt(self):
-        """Will decrypt a triplesec encrypted file.  Will decrypt file
-        passed in during object initialization or new_file method."""
+        """Will decrypt a triplesec encrypted file"""
         if self.filename is None:
             raise FileCryptError('Must set filename with new_file '
                                  'method call before you can decrypt',
                                  expected=True)
+        if not os.path.exists(self.enc_filename):
+            log.debug('No encrypted file to decrypt')
+            return
         if self.password is None:
             self._get_password()
         # Will check for cipertext created with the old
@@ -195,13 +196,9 @@ class FileCrypt(object):
     def _convert_encryption(self):
         username, app_name = self._make_username_appname()
         log.info('Looking for keyring password')
-        # Checking for keyring password.  If found assumes there could
-        # be a file encrypted with the old method.
         keyring_password = keyring.get_password(app_name, username)
         if keyring_password is not None and self.test is False:
             while self.tries < 3:
-                # Checking the entered password to see if it matches the
-                # one stored in the keyring.
                 if keyring_password == pbkdf2.crypt(self.password,
                                                     keyring_password):
                     self._update_timer()
@@ -216,20 +213,13 @@ class FileCrypt(object):
                 sys.exit(0)
 
             try:
-                # Will try to decrypt the file with triplesec.  If
-                # file cannot be decrypted then we know it needs to
-                # be converted. If it can be decrypted then there is
-                # nothing else to do here.
                 log.debug('Checking if already converted')
                 with open(self.enc_filename) as f:
                     enc_data = f.read()
                 data = triplesec.decrypt(enc_data, self.password)
-                # Deleting decrypted info from memory
                 del data
                 log.debug('Already converted encryption')
             except triplesec.utils.TripleSecError:
-                # Well looks like we need to convert the encryption
-                # to triplesec
                 log.info('Converting encryption for '
                          '{}:\n{}'.format(self.filename, cwd_))
                 beefish.decrypt_file(self.enc_filename, self.filename,
