@@ -26,6 +26,7 @@ import multiprocessing
 import os
 import re
 import shutil
+import sys
 
 try:
     import bsdiff4
@@ -39,7 +40,6 @@ from not_so_tuf.utils import (ChDir, ask_yes_no, _get_package_hashes,
                               _version_tuple_to_string,
                               FROZEN)
 
-
 log = logging.getLogger(__name__)
 
 
@@ -86,111 +86,51 @@ class PackageHandler(object):
         self.package_manifest = []
 
     def setup(self):
-        """Proxy method for :meth:`_setup_work_dirs` & :meth:`_load_json`
+        """Creates all needed working directories & loads version file.
+
+        Proxy method for :meth:`_setup_work_dirs` & :meth:`_load_json`
         """
         self._setup_work_dirs()
         self._load_json()
 
     def update_package_list(self):
-        """Proxy method for :meth:`_get_package_list`,
-        :meth:`_setup_file_dirs` & :meth:`_update_json`
+        """Gets a list of updates to process.  Adds the name of an
+        update to the version file if not already present.  Processes
+        all packages.  Updates the version file meta-data. Then writes
+        version file back to disk.
+
+        Proxy method for :meth:`_get_package_list`,
+        :meth:`_setup_file_dirs`, :meth:`_update_version_file` &
+        :meth:`_write_json_to_file`.
         """
         self._get_package_list()
         self._setup_file_dirs()
-        self._update_json()
+        self._update_version_file()
+        self._write_json_to_file()
 
     def deploy(self):
-        """Proxy method form :meth:`_move_packages`
+        """Moves updates/patches/version file to deploy folder
+
+        Proxy method form :meth:`_move_packages`
         """
         self._move_packages()
 
     def _setup_work_dirs(self):
-        """Sets up work dirs on dev machine.  Creates the following folder
-            - Data dir
-        Then inside the data folder it creates 3 more folders
-            - New - for new updates that need to be signed
-            - Deploy - All files ready to upload are placed here.
-            - Files - All updates are placed here for future reference
-        """
-        # Creates build directories if not already
-        # present.  This is non destructive
+        # Sets up work dirs on dev machine.  Creates the following folder
+        #    - Data dir
+        # Then inside the data folder it creates 3 more folders
+        #    - New - for new updates that need to be signed
+        #    - Deploy - All files ready to upload are placed here.
+        #    - Files - All updates are placed here for future reference
+        #
+        # This is non destructive
         log.info('Setting up work dirs...')
-        dirs = [self.data_dir, self.new_dir, self.deploy_dir,
-                self.files_dir]
+        dirs = [self.data_dir, self.new_dir, self.deploy_dir, self.files_dir]
         for d in dirs:
             if not os.path.exists(d):
                 os.mkdir(d)
 
-    def _setup_file_dirs(self):
-        """Creates sub directories under files directory. First level under
-        files dir are folders labeled after each signed file.  ie. lib1 dylib2.
-        Then under each folder named after a library are sub dirs labeled
-        with version numbers.
-        """
-        # Creates a director with update name
-        # Then creates sub directories with each update
-        # version
-        log.info('Setting up directories for file updates')
-        for p in self.package_manifest:
-            path = os.path.join(self.files_dir, p['name'])
-            self.version_path = os.path.join(path, p['version'])
-            p['version_path'] = self.version_path
-            if not os.path.exists(path):
-                os.mkdir(path)
-            if not os.path.exists(self.version_path):
-                os.mkdir(self.version_path)
-
-    # ToDo: Explain whats going on below &/or clean up
-    def _move_packages(self):
-        """Moves all packages to their destination folder.
-        Destination is figured by lib name and version number.
-        """
-        log.info('Moving packages to deploy folder')
-        for p in self.package_manifest:
-            patch = p.get('patch_name', None)
-            version_path = p['version_path']
-            with ChDir(self.new_dir):
-                if patch:
-                    shutil.copy(patch, self.deploy_dir)
-                    log.debug('Copying {} to {}'.format(patch,
-                                                        self.deploy_dir))
-                    shutil.move(patch, version_path)
-                    log.debug('Moving {} to {}'.format(patch, version_path))
-
-                shutil.copy(p['real_name'], self.deploy_dir)
-                log.debug('Copying {} to {}'.format(p['real_name'],
-                                                    self.deploy_dir))
-
-                if os.path.exists(os.path.join(version_path, p['real_name'])):
-                    msg = ('Version {} of {} already exists. '
-                           'Overwrite?'.format(p['version'], p['name']))
-                    answer = ask_yes_no(msg)
-                    if answer:
-                        shutil.rmtree(version_path, ignore_errors=True)
-                        # os.remove(version_path)
-                        os.mkdir(version_path)
-                        shutil.move(p['real_name'], version_path)
-                    else:
-                        continue
-                else:
-                    shutil.move(p['real_name'], version_path)
-                    log.debug('Moving {} to {}'.format(p['real_name'],
-                                                       version_path))
-
-        with ChDir(self.data_dir):
-            shutil.copy('version.json', self.deploy_dir)
-
-    def _update_json(self):
-        """Proxy method for :meth:`_update_version_file` &
-        :meth:`_write_json_to_file`
-        """
-        self._update_version_file()
-        self._write_json_to_file()
-
     def _load_json(self):
-        """Will try to load version file from file-system.  If no version file
-        is found then one will be created in memory and wrote to disk later
-        """
         # If version file is found its loaded to memory
         # If no version file is found then one is created.
         log.debug('Looking for version file...')
@@ -204,7 +144,7 @@ class PackageHandler(object):
                 if updates is None:
                     log.debug('Invalid data in version file...')
                     self.json_data['updates'] = {}
-                    log.debug('Created new version data')
+                    log.debug('Updated version file format')
         except Exception as e:
             log.error('Version file not found')
             log.error(e)
@@ -212,105 +152,9 @@ class PackageHandler(object):
             log.debug('Created new version file')
         log.info('Loaded version file')
 
-    def _write_json_to_file(self):
-        """Writes json data to disk"""
-        log.info('Writing version data to file')
-        with open(os.path.join(self.data_dir, 'version.json'), 'w') as f:
-            f.write(json.dumps(self.json_data, sort_keys=True,
-                    indent=4))
-
-    def _get_highest_version_number(self, package_name):
-        """Parses highest version number form given package_name
-
-        Args:
-            package_name (str): name of file to search for updates
-
-        Returns:
-            (str) Highest version number
-
-        """
-        log.debug('Getting highest version number')
-        return sorted(self.json_data['updates'][package_name].keys())[-1]
-
-    def _update_file_list(self, package_name):
-        """Checks version file for package_name.  If not present adds to
-        version file
-
-        Args:
-            package_name (str): Name of package to check against version file
-        """
-        log.info('Checking file list for {}'.format(package_name))
-        files = self.json_data['updates']
-        latest = self.json_data.get('latest', None)
-        package_name = self._remove_ext(self._remove_version_number(
-                                        package_name))
-        package_name = self._remove_platform(package_name)
-        file_name = files.get(package_name, None)
-        if file_name is None:
-            log.info('Adding {} to file list'.format(package_name))
-            self.json_data['updates'][package_name] = {}
-
-        if latest is None:
-            self.json_data['latest'] = {package_name: ''}
-
-    def _update_version_file(self):
-        """Updates version file with package meta-data
-        """
-        log.info('Starting version file update')
-        for p in self.package_manifest:
-            version = p['version']
-            name = p['name']
-            md5 = p['md5']
-            filename = p['filename']
-            info = {'md5': md5,
-                    'url': self.update_url + p['real_name'],
-                    'filename': filename}
-
-            # I don't know WTF is goin on here!
-            # Gotta figure out a patch naming scheme
-            patch_name = p.get('patch_name', None)
-            patch_hash = p.get('patch_md5', None)
-            if patch_name and patch_hash:
-                info['patch_name'] = patch_name
-                info['patch_md5'] = patch_hash
-                info['patch_url'] = self.update_url + patch_name
-
-            log.debug('json version {}'.format(self.json_data['updates']
-                      [name].get(version, None)))
-            if self.json_data['updates'][name].get(version, None) is None:
-                log.debug('Adding new version to file')
-
-                # ToDo: Remove once stable.  Here to help with
-                #       transition to new version file format
-                versions = self.json_data['updates'][name]
-                # Preforming check for y_data because this could be a new
-                # version file not requiring legacy support :)
-                if len(versions) <= 8 and \
-                        self.json_data.get('y_data', None) is not None:
-                    self.json_data['y_data'][name][version] = {}
-                    temp = self.json_data['y_data'][name]
-                    temp[version][p['platform']] = info
-
-                self.json_data['updates'][name][version] = {}
-                if self.json_data['updates'][name][version].get('platform',
-                                                                None) is None:
-                    name_ = self.json_data['updates'][name]
-                    name_[version][p['platform']] = info
-
-            else:
-                if len(versions) <= 8 and \
-                        self.json_data.get('y_data', None) is not None:
-                    y_temp = self.json_data['y_data'][name]
-                    y_temp[version][p['platform']] = info
-                log.debug('Appending info data to version file')
-                self.json_data['updates'][name][version][p['platform']] = info
-
-            self.json_data['latest'][name] = version
-
     def _get_package_list(self, ignore_errors=True):
-        """Adds compatible packages to internal package manifest
-        for futher processing
-        """
+        # Adds compatible packages to internal package manifest
+        # for futher processing
         # Process all packages in new folder and gets
         # url md5 and some outer info.
         log.info('Getting package list')
@@ -369,6 +213,147 @@ class PackageHandler(object):
             for b in bad_packages:
                 print b
 
+    def _setup_file_dirs(self):
+        # Creates a director with update name
+        # Then creates sub directories with each update
+        # version
+        log.info('Setting up directories for file updates')
+        for p in self.package_manifest:
+            path = os.path.join(self.files_dir, p['name'])
+            self.version_path = os.path.join(path, p['version'])
+            p['version_path'] = self.version_path
+            if not os.path.exists(path):
+                os.mkdir(path)
+            if not os.path.exists(self.version_path):
+                os.mkdir(self.version_path)
+
+    def _update_version_file(self):
+        # Updates version file with package meta-data
+        log.info('Starting version file update')
+        for p in self.package_manifest:
+            version = p['version']
+            name = p['name']
+            md5 = p['md5']
+            filename = p['filename']
+            patch_name = p.get('patch_name', None)
+            patch_hash = p.get('patch_md5', None)
+
+            # Converting info to version file format
+            info = {'md5': md5,
+                    'url': self.update_url + p['real_name'],
+                    'filename': filename}
+            if patch_name and patch_hash:
+                info['patch_name'] = patch_name
+                info['patch_md5'] = patch_hash
+                info['patch_url'] = self.update_url + patch_name
+
+            log.debug('json version {}'.format(self.json_data['updates']
+                      [name].get(version, None)))
+
+            # ToDo: Remove once stable.  Here to help with
+            #       transition to new version file format
+            versions = self.json_data['updates'][name]
+            if self.json_data['updates'][name].get(version, None) is None:
+                log.debug('Adding new version to file')
+
+                # Preforming check for y_data because this could be a new
+                # version file not requiring legacy support Also allowing
+                # up to 8 overlapping updates to ease transition :)
+                if len(versions) <= 8 and \
+                        self.json_data.get('y_data', None) is not None:
+                    self.json_data['y_data'][name][version] = {}
+                    temp = self.json_data['y_data'][name]
+                    temp[version][p['platform']] = info
+
+                # Getting ready to throw a new version in there
+                self.json_data['updates'][name][version] = {}
+                if self.json_data['updates'][name][version].get('platform',
+                                                                None) is None:
+                    name_ = self.json_data['updates'][name]
+                    name_[version][p['platform']] = info
+
+            else:
+                # Just adding another platform specific update
+                if len(versions) <= 8 and \
+                        self.json_data.get('y_data', None) is not None:
+                    y_temp = self.json_data['y_data'][name]
+                    y_temp[version][p['platform']] = info
+                log.debug('Appending info data to version file')
+                self.json_data['updates'][name][version][p['platform']] = info
+
+            # Will add each individual platform version update
+            # to latest.  Now can update platforms independently
+            # without version number mangling.
+            self.json_data['latest'][name][p['platform']] = version
+
+    def _write_json_to_file(self):
+        # Writes json data to disk
+        log.info('Writing version data to file')
+        with open(os.path.join(self.data_dir, 'version.json'), 'w') as f:
+            f.write(json.dumps(self.json_data, sort_keys=True, indent=4))
+
+    # ToDo: Explain whats going on below &/or clean up
+    def _move_packages(self):
+        # Moves all packages to their destination folder.
+        # Destination is figured by lib name and version number.
+        # Since we are copying files to the deploy folder then
+        # moving the updates to the files folder, we can safely
+        # delete files in deploy folder after uploading.
+        log.info('Moving packages to deploy folder')
+        for p in self.package_manifest:
+            patch = p.get('patch_name', None)
+            version_path = p['version_path']
+            with ChDir(self.new_dir):
+                if patch:
+                    shutil.copy(patch, self.deploy_dir)
+                    log.debug('Copying {} to {}'.format(patch,
+                                                        self.deploy_dir))
+                    shutil.move(patch, version_path)
+                    log.debug('Moving {} to {}'.format(patch, version_path))
+
+                shutil.copy(p['real_name'], self.deploy_dir)
+                log.debug('Copying {} to {}'.format(p['real_name'],
+                                                    self.deploy_dir))
+
+                if os.path.exists(os.path.join(version_path, p['real_name'])):
+                    msg = ('Version {} of {} already exists. '
+                           'Overwrite?'.format(p['version'], p['name']))
+                    answer = ask_yes_no(msg)
+                    if answer:
+                        shutil.rmtree(version_path, ignore_errors=True)
+                        os.mkdir(version_path)
+                        shutil.move(p['real_name'], version_path)
+                    else:
+                        continue
+                else:
+                    shutil.move(p['real_name'], version_path)
+                    log.debug('Moving {} to {}'.format(p['real_name'],
+                                                       version_path))
+
+        # I freaking love this chdir context manager!!!
+        with ChDir(self.data_dir):
+            shutil.copy('version.json', self.deploy_dir)
+
+    def _update_file_list(self, package_name):
+        # Checks version file for package_name.  If not present adds
+        # to version file
+        log.info('Checking file list for {}'.format(package_name))
+        files = self.json_data['updates']
+        latest = self.json_data.get('latest', None)
+        if latest is None:
+            self.json_data['latest'] = {}
+        package_name = self._remove_ext(self._remove_version_number(
+                                        package_name))
+        package_name = self._remove_platform(package_name)
+        file_name = files.get(package_name, None)
+        if file_name is None:
+            log.info('Adding {} to file list'.format(package_name))
+            self.json_data['updates'][package_name] = {}
+
+        latest_package = self.json_data['latest'].get(package_name, None)
+        if latest_package is None:
+            self.json_data['latest'][package_name] = {}
+
     def _package_plat_version_check(self, package):
         found = re.findall('-[macnixw64]{3,5}-[0-9]+\.[0-9]+\.[0-9]', package)
         if len(found) < 1:
@@ -385,21 +370,9 @@ class PackageHandler(object):
         return name
 
     def _check_make_patch(self, name, version, platform):
-        """Check to see if previous version is available to make patch updates
-        Also calculates patch number
-
-        Args:
-            name (str): name of folder to search in files dir
-
-            version (str): version to compare against
-
-        Returns:
-            (tuple) Meaning::
-
-                None - No src binary to make patch from
-
-                Tuple - (path to source file, patch number)
-        """
+        # Check to see if previous version is available to
+        # make patch updates
+        # Also calculates patch number
         if bsdiff4 is None:
             return None
         src_file_path = None
@@ -435,36 +408,14 @@ class PackageHandler(object):
             return src_file_path, len(_files) + 1
 
     def _remove_ext(self, filename):
-        """Removes file ext from filename.
-
-        Args:
-            filename (str): Filename to remove extension from
-
-        Returns:
-            (str) Filename without extension
-
-        Similar to os.path.basename::
-            filename = 'foo.tar.bz2'
-            >>> print os.path.basename(filename)
-            ('foo.tar', 'bz2')
-            >>> print _remove_ext(filename)
-            'foo'
-        """
-
+        # Removes file ext from filename.
         data = os.path.splitext(filename)
         while len(data[1]) > 0:
             data = os.path.splitext(data[0])
         return data[0]
 
     def _get_version_number(self, package_name):
-        """Parse package name and return version number
-
-        Args:
-            packange_name (str): Filename to parse for version number
-
-        Returns:
-            (str) Version Number
-        """
+        # Parse package name and return version number
         # Extracts and returns version number from
         # given string
         try:
@@ -476,14 +427,6 @@ class PackageHandler(object):
                                       expected=True)
 
     def _remove_version_number(self, package_name):
-        """Removes version number from filename
-
-        Args:
-            package_name (str): name of package to remove version number from
-
-        Returns:
-            (str): package_name without version number
-        """
         # Returns string with version number removed
         # What, thought it did something else? lol j/k
         reg = '-[0-9]+\.[0-9]+\.[0-9]+'
@@ -491,20 +434,6 @@ class PackageHandler(object):
 
 
 def _make_patch(patch_info):
-        """Makes patch
-
-        Args:
-            src_path (str): Path to src binary
-
-            dst_path (str): Path to dst binary
-
-            patch_name (str): Name to give created patch
-
-            patch_number (str): Number to append to patch name
-
-        Returns:
-            (str) Final patch name
-        """
         patch_name = patch_info['patch_name']
         patch_number = patch_info['patch_num']
         src_path = patch_info['src']
