@@ -68,18 +68,9 @@ class Patcher(object):
         self.plat = platform_
 
     def start(self):
-        """Proxy method for :meth:`_verify_installed_binary`,
-        :meth:`_get_all_patches`, :meth:`_download_verify_patches`,
-        :meth:`_apply_patches_in_memory` & :meth:`_write_update_to_disk`
-
-        Returns:
-            (bool) Meanings::
-
-                True - Patch update successful
-
-                False - Failed to pass at least 1 Check.  Failed patch update
+        """Starts patching process
         """
-        log.info('Starting patch updater...')
+        log.debug('Starting patch updater...')
         # Check hash on installed binary to begin patching
         binary_check = self._verify_installed_binary()
         if not binary_check:
@@ -101,15 +92,7 @@ class Patcher(object):
         return True
 
     def _verify_installed_binary(self):
-        """Verifies currently installed binary against known hash
-
-        Returns:
-            (bool) Meanings::
-
-                True - Binary verified
-
-                False - Binary not verified
-        """
+        # Verifies currently installed binary against known hash
         log.info('Checking for current installed binary to patch')
         file_info = self._get_current_filename_and_hash(self.name,
                                                         self.current_version)
@@ -135,19 +118,6 @@ class Patcher(object):
     # thats greater then the current version to the list
     # of needed patches.
     def _get_all_patches(self, name):
-        """Creates a list of patches to get from current binary to
-        latest binary
-
-        Args:
-            name (str): name of binary to get patches for.
-
-        Returns:
-            (bool) Meanings::
-
-                True - If all patches were found
-
-                False - Failed to find all patches
-        """
         needed_patches = []
         versions = []
         # ToDo: Remove once framework is stable.  All clients should
@@ -209,15 +179,7 @@ class Patcher(object):
         return True
 
     def _download_verify_patches(self):
-        """Downloads & verifies all patches
-
-        Returns:
-            (bool) Meanings::
-
-                True - All patches have been downloaded and verified
-
-                False - 1 or more patches failed to download and/or verify
-        """
+        # Downloads & verifies all patches
         log.debug('Downloading patches')
         for p in self.patch_data:
             fd = FileDownloader(p['patch_name'], p['patch_url'],
@@ -231,7 +193,7 @@ class Patcher(object):
         return True
 
     def _apply_patches_in_memory(self):
-        """Applies a sequence of patches in memory"""
+        # Applies a sequence of patches in memory
         log.info('Applying patches')
         # Beginning the patch process
         self.new_binary = self.og_binary
@@ -239,7 +201,7 @@ class Patcher(object):
             self.new_binary = bsdiff4.patch(self.new_binary, i)
 
     def _write_update_to_disk(self):
-        """Writes updated binary to disk"""
+        # Writes updated binary to disk
         log.info('Writing update to disk')
         # ToDo: Remove try/except block once stable
         #       Only keeping for compatibility reasons
@@ -253,18 +215,7 @@ class Patcher(object):
                 f.write(self.new_binary)
 
     def _get_current_filename_and_hash(self, name, version):
-        """Returns filename and hash for given name and version
-
-        Args:
-            name (str): Name of binary to search for
-            version (str): Version number to search for
-
-        Returns:
-            (dict) Meanings::
-
-                filename = dict['filename']
-                hash = dict['hash']
-        """
+        # Returns filename and hash for given name and version
         info = {}
         # ToDo: Remove try/except block once stable
         #       Only kept around for compatibility reasons
@@ -278,14 +229,7 @@ class Patcher(object):
         return info
 
     def _get_package_hashes(self, package):
-        """Get hash of provided package
-
-        Args:
-            package (str): Name of package to get hash from
-
-        Returns:
-            (str) md5 hash
-        """
+        # Get hash of provided package
         # Returns has of provided package
         log.debug('Getting package hashes')
         with open(package, 'rb') as f:
