@@ -23,6 +23,7 @@
 # Really Ugly Imports
 # Suggestions welcome
 import logging
+import os
 import sys
 
 try:
@@ -82,6 +83,7 @@ class S3Uploader(BaseUploader):
                                                        cb=self.s3_progress)
                 self.client.make_public()
                 print('Did that upload boy')
+                os.remove(filename)
                 return True
             except Exception as e:
                 log.error(str(e), exc_info=True)
